// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.cardboard;

import java.util.List;
import java.util.ArrayList;

/**
 * Abstract CardBoardModel implementation.
 *
 * Provides methods to register remove listeners.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastModifiedBy$
 * @version $Id: AbstractCardBoardModel.java 83 2004-04-13 13:51:09Z jerome $
 */
public abstract class AbstractCardBoardModel implements CardBoardModel
{
  /** the list of listeners. */
  private final List _boardListeners = new ArrayList();


  /**
   * Adds the specified listener to the instance's listener's list.
   * @param listener the listener to add
   */
  public void addBoardDataListener(final CardBoardModelListener listener)
  {
    _boardListeners.add(listener);
  }

  /**
   * Removes the specified listener to the instance's listener's list.
   * @param listener the listener to remove
   */
  public void removeBoardDataListener(final CardBoardModelListener listener)
  {
    _boardListeners.remove(listener);
  }

  /**
   * Fire the specified contents changed event
   * @param event
   * @see CardBoardModelListener#contentsChanged(org.cb.cardboard.CardBoardEvent)
   */
  protected final void fireContentsChanged(final CardBoardEvent event)
  {
    if (_boardListeners != null)
    {
      for (int i = 0; i < _boardListeners.size(); i++)
      {
        final CardBoardModelListener boardListenerIF = (CardBoardModelListener) _boardListeners.get(i);
        boardListenerIF.contentsChanged(event);
      }
    }
  }

  /**
   * Fire the specified interval added event
   * @param event
   * @see CardBoardModelListener#intervalAdded(org.cb.cardboard.CardBoardEvent)
   */
  protected final void fireIntervalAdded(final CardBoardEvent event)
  {
    if (_boardListeners != null)
    {
      for (int i = 0; i < _boardListeners.size(); i++)
      {
        final CardBoardModelListener boardListenerIF = (CardBoardModelListener) _boardListeners.get(i);
        boardListenerIF.intervalAdded(event);
      }
    }
  }

  /**
   * Fire the specified interval removed event
   * @param event
   * @see CardBoardModelListener#intervalRemoved(org.cb.cardboard.CardBoardEvent)
   */
  protected final void fireIntervalRemoved(final CardBoardEvent event)
  {
    if (_boardListeners != null)
    {
      for (int i = 0; i < _boardListeners.size(); i++)
      {
        final CardBoardModelListener boardListenerIF = (CardBoardModelListener) _boardListeners.get(i);
        boardListenerIF.intervalRemoved(event);
      }
    }
  }
}
