// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.cardboard;

import java.awt.Component;

/**
 * Interface to a renderer of a card of a board.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastModifiedBy$
 * @version $Id: BoardCardRenderer.java 78 2004-04-13 04:25:57Z jerome $
 */
public interface BoardCardRenderer
{
  /**
   * Return a component that has been configured to display the specified
   * value. That component's <code>paint</code> method is then called to
   * "render" the card.  If it is necessary to compute the dimensions
   * of a board because the board cards do not have a fixed size, this method
   * is called to generate a component on which <code>getPreferredSize</code>
   * can be invoked.
   *
   * @param cardBoard The JCardBoard we're painting.
   * @param value The value returned by list.getModel().getElementAt(index).
   * @param index The cells index.
   * @param isSelected True if the specified cell was selected.
   * @param cardHasFocus True if the specified cell has the focus.
   * @return A component whose paint() method will render the specified value.
   *
   * @see org.cb.cardboard.JCardBoard
   * @see org.cb.cardboard.BoardSelectionModel
   * @see org.cb.cardboard.CardBoardModel
   */
  Component getBoardCardRendererComponent(
      JCardBoard cardBoard,
      Card value,
      int index,
      boolean isSelected,
      boolean cardHasFocus);

}
