// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.cardboard;

import java.util.List;

/**
 * This interface defines the methods components like JCardBoard use
 * to get the value of each card in a board and the length of the list.
 * Logically the model is a vector, indices vary from 0 to
 * CardBoardModel.getSize() - 1.  Any change to the contents or
 * length of the data model must be reported to all of the
 * CardBoardModelListener.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: CardBoardModel.java 123 2004-04-14 23:45:53Z jerome $
 */
public interface CardBoardModel
{
  /**
   * Returns the number of cards on the board.
   * @return the length of the list
   */
  int getSize();

  /**
   * Returns the value at the specified index.
   * @param index the requested index
   * @return the value at <code>index</code>
   */
  Card getElementAt(int index);


  /**
   * @return all the values.
   */
  List getElements();

  /**
   * Adds a listener to the list that's notified each time a change
   * to the data model occurs.
   * @param listener the <code>CardBoardModelListener</code> to be added
   */
  void addBoardDataListener(CardBoardModelListener listener);

  /**
   * Removes a listener from the list that's notified each time a
   * change to the data model occurs.
   * @param listener the <code>CardBoardModelListener</code> to be removed
   */
  void removeBoardDataListener(CardBoardModelListener listener);
}
