// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.cardboard;

import java.util.EventListener;

/**
 * An interface that all CardBoardModel listeners must implement.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: CardBoardModelListener.java 129 2004-04-15 05:00:43Z jerome $
 */
public interface CardBoardModelListener extends EventListener
{
  /**
   * Sent after the indices in the index0,index1
   * interval have been inserted in the data model.
   * The new interval includes both index0 and index1.
   *
   * @param e  a <code>CardBoardEvent</code> encapsulating the
   *    event information
   */
  void intervalAdded(CardBoardEvent e);


  /**
   * Sent after the indices in the index0,index1 interval
   * have been removed from the data model.  The interval
   * includes both index0 and index1.
   *
   * @param e  a <code>CardBoardEvent</code> encapsulating the
   *    event information
   */
  void intervalRemoved(CardBoardEvent e);


  /**
   * Sent when the contents of the board has changed in a way
   * that's too complex to characterize with the previous
   * methods. For example, this is sent when an item has been
   * replaced. Index0 and index1 bracket the change.
   *
   * @param e  a <code>CardBoardEvent</code> encapsulating the
   *    event information
   */
  void contentsChanged(CardBoardEvent e);

}
