// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.cardboard;

import javax.swing.plaf.ComponentUI;
import java.awt.Point;
import java.awt.Rectangle;

/**
 * The JCardBoard pluggable look and feel delegate.  This interface adds
 * methods that allow the JCardBoard component to map locations, e.g. mouse
 * coordinates, to board cards and from card indices to the bounds of
 * the card.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastModifiedBy$
 * @version $Id: CardBoardUI.java 129 2004-04-15 05:00:43Z jerome $
 */
public abstract class CardBoardUI extends ComponentUI
{
  /**
   * Convert a point in <code>JCardBord</code> coordinates to the closest index
   * of the card at that location. To determine if the card actually
   * contains the specified location use a combination of this method and
   * <code>getCardBounds</code>.  Returns -1 if the model is empty.
   *
   * @param board the board for which this instance delegates the look and feel
   * @param location The JCardBoard relative coordinates of the card
   * @return The index of the cell at location, or -1.
   */
  public abstract int locationToIndex(final JCardBoard board, final Point location);


  /**
   * Returns the origin of the specified item in JCardBoard
   * coordinates, null if index isn't valid.
   *
   * @param board the board for which this instance delegates the look and feel
   * @param index The index of the JCardBoard cell.
   * @return The origin of the index'th cell.
   */
  public abstract Point indexToLocation(final JCardBoard board, final int index);


  /**
   * Returns the bounds of the specified item in JCardBoard
   * coordinates, null if index isn't valid.
   *
   * @param board the board for which this instance delegates the look and feel
   * @param index1 The index of the JCardBoard cell.
   * @param index2 The index of the JCardBoard cell.
   * @return The bounds of the index'th cell.
   */
  public abstract Rectangle getCardBounds(final JCardBoard board,
                                          final int index1,
                                          final int index2);

}
