// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.cardboard;

import javax.swing.*;
import javax.swing.event.EventListenerList;

/**
 * Default data model for board selections.
 * <p>
 * we shamely reuse the DefaultListSelectionModel interface & adapts its implementation.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastModifiedBy$
 * @version $Id: DefaultBoardSelectionModel.java 123 2004-04-14 23:45:53Z jerome $
 */
public class DefaultBoardSelectionModel implements BoardSelectionModel
{
  /** the adapted <code>DefaultListSelectionModel</code> instance. */
  private final DefaultListSelectionModel _adaptee = new DefaultListSelectionModel();
  /** the listener list. */
  private final EventListenerList _listenerList = new EventListenerList();

  public void setSelectionInterval(final int index0, final int index1)
  {
    _adaptee.setSelectionInterval(index0, index1);
  }

  public void addSelectionInterval(final int index0, final int index1)
  {
    _adaptee.addSelectionInterval(index0, index1);
  }

  public void removeSelectionInterval(final int index0, final int index1)
  {
    _adaptee.removeSelectionInterval(index0, index1);
  }

  public int getMinSelectionIndex()
  {
    return _adaptee.getMinSelectionIndex();
  }

  public int getMaxSelectionIndex()
  {
    return _adaptee.getMaxSelectionIndex();
  }

  public boolean isSelectedIndex(final int index)
  {
    return _adaptee.isSelectedIndex(index);
  }

  public int getAnchorSelectionIndex()
  {
    return _adaptee.getAnchorSelectionIndex();
  }

  public void setAnchorSelectionIndex(final int index)
  {
    _adaptee.setAnchorSelectionIndex(index);
  }

  public int getLeadSelectionIndex()
  {
    return _adaptee.getLeadSelectionIndex();
  }

  public void setLeadSelectionIndex(final int index)
  {
    _adaptee.setLeadSelectionIndex(index);
  }

  public void clearSelection()
  {
    _adaptee.clearSelection();
  }

  public boolean isSelectionEmpty()
  {
    return _adaptee.isSelectionEmpty();
  }

  public void insertIndexInterval(final int index, final int length, final boolean before)
  {
    _adaptee.insertIndexInterval(index, length, before);
  }

  public void removeIndexInterval(final int index0, final int index1)
  {
    _adaptee.removeIndexInterval(index0, index1);
  }

  public void setValueIsAdjusting(final boolean valueIsAdjusting)
  {
    _adaptee.setValueIsAdjusting(valueIsAdjusting);
  }

  public boolean getValueIsAdjusting()
  {
    return _adaptee.getValueIsAdjusting();
  }

  public void setSelectionMode(final int selectionMode)
  {
    _adaptee.setSelectionMode(selectionMode);
  }

  public int getSelectionMode()
  {
    return _adaptee.getSelectionMode();
  }

  public void addBoardSelectionListener(final BoardSelectionListener x)
  {
    _listenerList.add(BoardSelectionListener.class, x);
  }

  public void removeBoardSelectionListener(final BoardSelectionListener x)
  {
    _listenerList.remove(BoardSelectionListener.class, x);
  }
}
