// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset;

import java.io.Serializable;

/**
 * A CardSet of cards in the game.
 * A set can be {@link #isMatching() matching} or not.
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: CardSet.java 129 2004-04-15 05:00:43Z jerome $
 */
public class CardSet implements Serializable
{
  private final CardProperties[] _set;

  /**
   * Creates a new instance of CardSet given the specified card properties.
   * @param set the potential matching set
   */
  public CardSet(final CardProperties[] set)
  {
    _set = set;
  }

  /**
   * @return the cards in the set
   * @todo do not expose the array like that. An Immutabble list could do it.
   */
  public CardProperties[] getCards()
  {
    return _set;
  }

  /**
   * @return <code>true</code> if the set is matching, <code>false</code> otherwise.
   */
  public boolean isMatching()
  {
    final CardProperties[] cards = getCards();
    if (cards.length != 3)
    {
      return false;
    }

    if ((cards[0].getShape() == cards[1].getShape() &&
         cards[1].getShape() != cards[2].getShape())
     || (cards[0].getShape() != cards[1].getShape() &&
         cards[1].getShape() == cards[2].getShape()))
    {
      return false;
    }
    if ((cards[0].getColor() == cards[1].getColor() &&
         cards[1].getColor() != cards[2].getColor())
     || (cards[0].getColor() != cards[1].getColor() &&
         cards[1].getColor() == cards[2].getColor()))
    {
      return false;
    }
    if ((cards[0].getNumber() == cards[1].getNumber() &&
         cards[1].getNumber() != cards[2].getNumber())
     || (cards[0].getNumber() != cards[1].getNumber() &&
         cards[1].getNumber() == cards[2].getNumber()))
    {
      return false;
    }
    if ((cards[0].getFill() == cards[1].getFill() &&
         cards[1].getFill() != cards[2].getFill())
     || (cards[0].getFill() != cards[1].getFill() &&
         cards[1].getFill() == cards[2].getFill()))
    {
      return false;
    }
    return true;
  }

  /**
   * @return a <code>String</code> representation of that object.
   */
  public String toString()
  {
    final StringBuffer buf = new StringBuffer("CardSet:");
    buf.append(CardProperties.toString(_set));
    return buf.toString();
  }

  /**
   * @todo move to unit test 
   * @param args
   */
  public static void main(final String[] args)
  {
    final CardProperties card1 = new CardProperties(1, 1, 1, 1);
    final CardProperties card2 = new CardProperties(2, 1, 2, 1);
    final CardProperties card3 = new CardProperties(3, 1, 3, 1);
    final CardProperties[] cards = {card1, card2, card3};

    System.out.println(new CardSet(cards).isMatching());
  }
}
