// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset;

import java.io.Serializable;
import java.util.Vector;
import java.util.List;

/**
 * Helps to find sets of matching cards in a List of cards.
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: MatchingSetFinder.java 78 2004-04-13 04:25:57Z jerome $
 */
public class MatchingSetFinder implements Serializable
{
  /**
   * Find the matching sets in the specified list of cards.
   * @param cards the list of cards. May contain null elements.
   * @return an array of matching <code>CardSet</code>s.
   */
  public CardSet[] findSets(final List cards)
  {
    final Vector v = new Vector();
    // CardProperties c1, c2, c3;
    JSetCard tmp;
    CardProperties c1, c2, c3;
    for (int i = 0; i < cards.size(); i++)
    {
      tmp = ((JSetCard) cards.get(i));
      if (tmp == null)
      {
       continue;
      }
      c1 = tmp.getProperties();
      for (int j = i + 1; j < cards.size(); j++)
      {
        tmp = ((JSetCard) cards.get(j));
        if (tmp == null)
        {
         continue;
        }
        c2 = tmp.getProperties();
        for (int k = j + 1; k < cards.size(); k++)
        {
          tmp = ((JSetCard) cards.get(k));
          if (tmp == null)
          {
           continue;
          }
          c3 = tmp.getProperties();
          // not the most beautifull implementation but one of the fastest
          // here the implementation assumes that for each property the sum of the different values
          // is a multiple of 3
          // Works pretty well with 1, 2, 3
          final byte colors = (byte) (c1.getColor() + c2.getColor() + c3.getColor());
          final byte numbers = (byte) (c1.getNumber() + c2.getNumber() + c3.getNumber());
          final byte types = (byte) (c1.getShape() + c2.getShape() + c3.getShape());
          final byte fills = (byte) (c1.getFill() + c2.getFill() + c3.getFill());
          if ((colors % 3 == 0) && (numbers % 3 == 0) && (types % 3 == 0) && (fills % 3 == 0))
          {
            final CardProperties[] prop = new CardProperties[3];
            prop[0] = c1;
            prop[1] = c2;
            prop[2] = c3;
            v.add(new CardSet(prop));
          }
        }
      }
    }
    final CardSet[] s = new CardSet[v.size()];
    return (CardSet[]) v.toArray(s);
  }
}
