// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset;

/**
 * Interface that board implementation must implement.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: SetGameBoard.java 129 2004-04-15 05:00:43Z jerome $
 */
interface SetGameBoard
{
  /**
   * @return the cards on the board.
   */
  CardProperties[] getCards();

  /**
   * @return the number of cards on the board.
   */
  int getNbCards();

  /**
   * Add the specified cards onto the board.
   * @param cards a non-<code>null</code> array, containing non-<code>null</code> elements.
   */
  void addCards(CardProperties[] cards);

  /**
   * Tries to match the specified set on this board.
   * @param set the set to remove
   * @throws MatchingException if the specified set is not matching
   * @throws BoardException if one of the set card is not on the board.
   */
  void matchSet(CardSet set) throws MatchingException, BoardException;

  /**
   * Adds a listener to this board. Does nothing if <code>null</code> is passed as argument.
   * @param boardListener the listener to add
   */
  void addBoardListener(SetGameBoardListener boardListener);

  /**
   * Removes a listener from this board. Does nothing if <code>null</code> is passed as argument.
   * @param boardListener the listener to remove
   */
  void removeBoardListener(SetGameBoardListener boardListener);
}
