// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset;

/**
 * An interface for a game connection.
 *<p>
 * GameConnection instances are delivered to a {@link SetGamePlayer} holder by a {@link SetGame} in order for the player
 * to perform operations.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: SetGameConnection.java 117 2004-04-14 23:16:04Z jerome $
 */
public interface SetGameConnection
{
  /**
   * Used by a registered player to try to match a set of cards.
   * @param set the set to try to match.
   * @throws MatchingException if the set doesn't match or if a card is not on the board.
   */
  void matchSet(CardSet set) throws MatchingException;

  /**
   * Close the game connection, effectively leaving the game.
   */
  void close();

  /**
   * Say wether the game connection is closed or not.
   * @return <code>true</code> if the connection is closed, <code>false</code> otherwise.
   */
  boolean isClosed();
}
