// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.client;

import org.cb.jset.SetGameBoardListener;
import org.cb.jset.CardProperties;
import org.cb.jset.CardSet;

import javax.swing.event.EventListenerList;

/**
 * An abstract <code>SetGame</code>, responsible of the event management. 
 *
 * @author jerome@coffeebreaks.org - last modified by $LastModifiedBy$
 * @version $Id: AbstractGame.java 123 2004-04-14 23:45:53Z jerome $
 */
public abstract class AbstractGame implements SetGame
{
  protected final EventListenerList _listenerList = new EventListenerList();

  // void addPlayersListener()
  public void addBoardListener(final SetGameBoardListener listener)
  {
    _listenerList.add(SetGameBoardListener.class, listener);
  }

  public void removeBoardListener(final SetGameBoardListener listener)
  {
    _listenerList.remove(SetGameBoardListener.class, listener);
  }

  public void addGameListener(final SetGameListener listener)
  {
    _listenerList.add(SetGameListener.class, listener);
  }

  public void removeGameListener(final SetGameListener listener)
  {
    _listenerList.remove(SetGameListener.class, listener);
  }


  protected void fireGameChange(final GameEvent event)
  {
    // Guaranteed to return a non-null array
    final Object[] listeners = _listenerList.getListenerList();
    // Process the listeners last to first, notifying
    // those that are interested in this event
    for (int i = listeners.length - 2; i >= 0; i -= 2)
    {
      if (listeners[i] == SetGameListener.class)
      {
        ((SetGameListener) listeners[i + 1]).gameChange(event);
      }
    }
  }

  protected void fireCardsAdded(final CardProperties[] cards)
  {
    // Guaranteed to return a non-null array
    final Object[] listeners = _listenerList.getListenerList();
    // Process the listeners last to first, notifying
    // those that are interested in this event
    for (int i = listeners.length - 2; i >= 0; i -= 2)
    {
      if (listeners[i] == SetGameBoardListener.class)
      {
        ((SetGameBoardListener) listeners[i + 1]).cardsAdded(cards);
      }
    }
  }

  protected void fireSetRemoved(final CardSet set)
  {
    // Guaranteed to return a non-null array
    final Object[] listeners = _listenerList.getListenerList();
    // Process the listeners last to first, notifying
    // those that are interested in this event
    for (int i = listeners.length - 2; i >= 0; i -= 2)
    {
      if (listeners[i] == SetGameBoardListener.class)
      {
        ((SetGameBoardListener) listeners[i + 1]).setRemoved(set);
      }
    }
  }
}
