// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.client;

import org.cb.jset.JSetGameImpl;
import org.cb.jset.SetGamePlayer;
import org.cb.jset.SetGameConnection;
import org.cb.jset.CardProperties;
import org.cb.jset.CardSet;
import org.cb.jset.MatchingException;


/**
 * A Game implementation to play localy.
 *
 * FIXME GameListener not registered.
 * @author jerome@coffeebreaks.org - last modified by $LastModifiedBy$
 * @version $Id: LocalGame.java 130 2004-04-15 05:18:07Z jerome $
 */
public class LocalGame extends AbstractGame
{
  private JSetGameImpl _game;
  private SetGamePlayer _player;
  private SetGameConnection _connection;
  private String _playerName = "Me";
  private boolean _isBlocked = false;
//  private boolean _wasDisconnected = false;

  public void start()
  {
    _game = new JSetGameImpl("Standalone", 1);
    _game.start();
    _player = initPlayer();
    _connection = _game.connect(_player);
  }

  SetGamePlayer initPlayer()
  {
    return new MyPlayer();
  }

  public boolean isBlocked()
  {
    return _isBlocked;
  }

  public String getPlayerName()
  {
    return _playerName;
  }

  /**
   * An implementation of a player for this local game.
   */
  class MyPlayer implements SetGamePlayer
  {
    /**
     * @return the name of the player.
     */
    public String getName()
    {
      return getPlayerName();
    }

    /**
     * Called by a game when the player should be blocked.
     * @see #isBlocked()
     */
    public void block()
    {
      _isBlocked = true;
    }

    /**
     * Called by a game when the player should be unblocked.
     * @see #isBlocked()
     */
    public void unblock()
    {
     _isBlocked = false;
    }

    /**
     * A blocked player doesn't have the right to play.
     * @return <code>true</code> is the player is blocked, <code>false</code> otherwise.
     */
    public boolean isBlocked()
    {
      return _isBlocked;
    }

    /**
     * Called to notify a disconnection from a game.
     */
    public void disconnect()
    {
  //    _wasDisconnected = true;
      LocalGame.this.fireGameChange(new GameEvent(GameEvent.END));
    }

    /**
     * @inheritDoc
     */
    public void cardsAdded(final CardProperties[] cards)
    {
      LocalGame.this.fireCardsAdded(cards);
    }

    /**
     * @inheritDoc
     */
    public void setRemoved(final CardSet set)
    {
      LocalGame.this.fireSetRemoved(set);
    }
  }

  public void stop()
  {
    _connection.close();
  }

  public void endTurn()
  {
    throw new IllegalStateException("FIXME: not implemented");
  }

  public void removeSet(final CardSet set) throws MatchingException
  {
    _connection.matchSet(set);
  }
}
