// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.client.ui;

import javax.swing.JPanel;
import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JWindow;
import java.awt.FlowLayout;
import java.awt.Color;
import java.awt.Image;

import org.cb.jset.CardProperties;
import org.cb.jset.JSetCard;

/**
 * A small class to help build a logo.
 *
 * Would be nice to have a way to close it...
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: JSetClientUI.java 85 2004-04-13 14:29:08Z jerome $
 */
public class JSetLogo extends JWindow
{
  private final JPanel _logoPanel = new JPanel();

  /**
   * Constructs a JSetLogo instance.
   */
  public JSetLogo()
  {
    init();
  }

  /*
  class JLogoName extends JComponent
  {
    private final AffineTransform at = new AffineTransform();
    private TextLayout _textTl;
    private final String _logoName = "JSet";

    public JLogoName()
    {
      init();
    }

    void init()
    {
      _textTl = new TextLayout(_logoName,
                               new Font("Helvetica", 3, 16),
                               new FontRenderContext(null, false, false));
      AffineTransform textAt = new AffineTransform();
      textAt.translate(0, (float)_textTl.getBounds().getHeight());
    }

    protected void paintComponent(final Graphics g)
    {
      super.paintComponent(g);

      Graphics2D g2 = (Graphics2D) g;
      Dimension d = getSize();
      int w = d.width;
      int h = d.height;

      float width = (float) _textTl.getBounds().getWidth();
      float height = (float) _textTl.getBounds().getHeight();
      final float v = w/2-width/2;
      AffineTransform at = new AffineTransform();
      at.rotate(Math.toRadians(-6));
      g2.transform(at);

      g2.setPaint(new GradientPaint(0, 0, Color.darkGray, w-50, h, Color.orange, false));
      _textTl.draw(g2, v, 15);
    }
  }
  */

  /**
   * initialize the contents of the JWindow representing the logo.
   */
  private void init()
  {

    this.getContentPane().add(_logoPanel);
    _logoPanel.setLayout(null);
    this.pack();
    this.setBounds(50, 50, 82, 108);

    JPanel lPanel;
    final int distanceFromCenter = 18;
    final int centerX = 20;
    final int centerY = 20;

    // unused for now...
//    {
//      JLogoName logoName = new JLogoName();
//      logoName.setSize(50, 30);
//      logoName.setBounds(37, centerY + 3 * distanceFromCenter,
//                        logoName.getWidth(), logoName.getHeight());
//      logoName.setPreferredSize(logoName.getPreferredSize());
//
//      _logoPanel.add(logoName);
//    }
    {
      final org.cb.jset.JSetCard card3 =
          new JSetCard(new CardProperties((byte) 3, (byte) 3, (byte) 1, (byte) 3));
      final int x = centerX;
      final int y = centerY + distanceFromCenter;
      lPanel = createCardPanel(card3, x, y);
      _logoPanel.add(lPanel);
    }
    {
      final org.cb.jset.JSetCard card1 =
          new JSetCard(new CardProperties((byte) 1, (byte) 1, (byte) 1, (byte) 1));
      final int x = (int) (centerX - distanceFromCenter * Math.sqrt(3) / 2);
      final int y = (int) (centerY - distanceFromCenter / 2);
      lPanel = createCardPanel(card1, x, y);
      _logoPanel.add(lPanel);
    }
    {
      final org.cb.jset.JSetCard card2 =
          new JSetCard(new CardProperties((byte) 2, (byte) 2, (byte) 1, (byte) 2));
      final int x = (int) (centerX + distanceFromCenter * Math.sqrt(3) / 2);
      final int y = (int) (centerY - distanceFromCenter);
      lPanel = createCardPanel(card2, x, y);
      _logoPanel.add(lPanel);
    }
  }

  /**
   * Saves the logo in a file.
   * Note: not implemented right now
   *
   * @param filePath the path where the image will be contained
   * @todo implement the save image functionality. We probably need to specify image type (e.g. png)
   */
  void saveLogo(final String filePath)
  {
    Image image = this.createImage(this.getWidth(), this.getHeight());
    // FIXME would be nice to be able to save this image somwehere. Find a way...
  }

  /**
   * Helper method to create a small panel containing the specified card, located
   * at the specified coordinates.
   * @param card1
   * @param x
   * @param y
   * @return
   */
  private JPanel createCardPanel(final JSetCard card1, final int x, final int y)
  {
    JComponent lCard;
    JPanel lPanel;
    lCard = new JSetCardComponent(card1).getShape(0);
    lCard.setSize(32, 52);
    lCard.setPreferredSize(lCard.getSize());
    lPanel = new JPanel();
    lPanel.setLayout(new FlowLayout());
    lPanel.setSize(42, 64);
    lPanel.setBackground(Color.white);
    lPanel.setPreferredSize(lPanel.getSize());
    lPanel.add(lCard);
    lPanel.setBounds(x, y, lPanel.getWidth(), lPanel.getHeight());
    lPanel.setBorder(BorderFactory.createLineBorder(Color.black));
    return lPanel;
  }

  /**
   * Start and show the logo.
   * @param args the arguments
   */
  public static void main(final String[] args)
  {
    final JSetLogo logo = new JSetLogo();
    logo.show();
  }
}
