// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.server;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Remote interface to the GameServer.
 * <p>
 * The main method is the {@link #connect(org.cb.jset.server.RemoteSetGamePlayer)} one which
 * provides the registering client a connection with which it can interact with the current
 * game.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: RemoteSetGame.java 117 2004-04-14 23:16:04Z jerome $
 */
public interface RemoteSetGame extends Remote
{
  /**
   * @param player the remote player
   * @return the remote game connection
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGame#connect(org.cb.jset.SetGamePlayer)
   */
  RemoteSetGameConnection connect(RemoteSetGamePlayer player) throws RemoteException;

  /**
   * @return the game id
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGame#getID()
   */
  int getID() throws RemoteException;

  /**
   * @return the game name
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGame#getName()
   */
  String getName() throws RemoteException;

  /**
   * @return the max number of players
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGame#getMaxNbPlayers()
   */
  int getMaxNbPlayers() throws RemoteException;

  /**
   * @return the current number of players
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGame#getCurrentNbPlayers()
   */
  int getCurrentNbPlayers() throws RemoteException;
}
