// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.server;

import org.cb.jset.CardProperties;
import org.cb.jset.CardSet;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Interface that remote Board listeners must implement.
 * <p>
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: RemoteSetGameBoardListener.java 118 2004-04-14 23:17:27Z jerome $
 */
public interface RemoteSetGameBoardListener extends Remote
{
  /**
   * Called to notify that the specified cards were added to the board.
   * @param cards the cards that were added to the board.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGameBoardListener#cardsAdded(org.cb.jset.CardProperties[])
   */
  void cardsAdded(CardProperties[] cards) throws RemoteException;

  /**
   * Called to notify that the specified set was removed from the board.
   * The set should be a {@link CardSet#isMatching() matching set}.
   * @param set the set that was removed from the board
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGameBoardListener#setRemoved(org.cb.jset.CardSet)
   */
  void setRemoved(CardSet set) throws RemoteException;
}
