// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.server;

import org.cb.jset.CardSet;
import org.cb.jset.MatchingException;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * An interface for Remote {@link org.cb.jset.SetGameConnection}.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: RemoteSetGameConnection.java 130 2004-04-15 05:18:07Z jerome $
 */
public interface RemoteSetGameConnection extends Remote
{
  /**
   * Used by a registered player to try to match a set of set.
   * @param set the set to try to match.
   * @throws MatchingException if the set doesn't match or if a card is not on the board.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGameConnection#matchSet(org.cb.jset.CardSet)
   */
  void matchSet(CardSet set) throws RemoteException, MatchingException;

  /**
   * Close the game connection, effectively leaving the game.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGameConnection#close()
   */
  void close() throws RemoteException;

  /**
   * Say wether the game connection is closed or not.
   * @return <code>true</code> if the connection is closed, <code>false</code> otherwise.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGameConnection#isClosed()
   */
  boolean isClosed() throws RemoteException;
}
