// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.server;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Interface for the clients to play remotely a jset game.
 * Defines the callbacks hooks made from the RemoteSetGame implementation to the remote client
 * implementing this interface.
 * <p>
 * @see RemoteSetGame#connect(org.cb.jset.server.RemoteSetGamePlayer)
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: RemoteSetGamePlayer.java 118 2004-04-14 23:17:27Z jerome $
 */
public interface RemoteSetGamePlayer extends Remote, org.cb.jset.server.RemoteSetGameBoardListener
{
  /**
   * @return the name of the player.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGamePlayer#getName()
   */
  String getName() throws RemoteException;

  /**
   * Called by a game when the player should be blocked.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGamePlayer#block()
   */
  void block() throws RemoteException;

  /**
   * Called by a game when the player should be unblocked.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGamePlayer#unblock()
   */
  void unblock() throws RemoteException;

  /**
   * A blocked player doesn't have the right to play.
   * @return <code>true</code> is the player is blocked, <code>false</code> otherwise.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGamePlayer#isBlocked()
   */
  boolean isBlocked() throws RemoteException;

  /**
   * Called to notify a disconnection from a game.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @see org.cb.jset.SetGamePlayer#disconnect()
   */
  void disconnect() throws RemoteException;
}
