// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.server;

import java.rmi.Remote;

/**
 * A Remote server that references the different <code>RemoteSetGame</code> available.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: RemoteSetGameServer.java 130 2004-04-15 05:18:07Z jerome $
 */
public interface RemoteSetGameServer extends Remote
{
  /**
   * @return the different remote games known to this server.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   */
  RemoteSetGame[] getGames() throws java.rmi.RemoteException;

  /**
   * Returns the game identified by the specified id.
   * @param id the id of the game to return
   * @return the game if found, or <code>null</code> if none found.
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   */
  RemoteSetGame getGame(int id) throws java.rmi.RemoteException;

  /**
   * Create a game with the specified number of players.
   * @param name the name of the game.
   * @param nbPlayers the number of players.
   * @return the new game id
   * @throws java.rmi.RemoteException upon communication related exception on this remote call
   * @todo specify what happens if exising name with same name exists.
   */
  int createGame(String name, int nbPlayers) throws java.rmi.RemoteException;
}
