// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset;

import java.util.Collection;

/**
 * Test Case that automatically initializes Log4J.
 *
 * @author jerome@coffeebreaks.org - last modified by $LastChangedBy: jerome $
 * @version $Id: BaseTestCase.java 78 2004-04-13 04:25:57Z jerome $
 */
public class BaseTestCase extends junit.framework.TestCase
{
  /** Log4J conf file for tests */
  public static final String LOG4J_CONF = "src/conf/test.log4j.properties";

  static
  {
    // check if assertions are enabled...
    boolean assertionsEnabled = false;
    assert (assertionsEnabled = true) : "side effect to set up assertionsEnabled value - not a real assertion - always true";
    System.out.println("------------ Assertions " + (assertionsEnabled ? "ENABLED" : "DISABLED") + " ------------");

    System.out.println("------------ CONFIGURING LOG4J ---------------");
    org.apache.log4j.PropertyConfigurator.configure(LOG4J_CONF);

    // this is nice but not appropriate in batch run test cases
    /*
    try
    {
      org.apache.log4j.lf5.DefaultLF5Configurator.configure();
    }
    catch (java.io.IOException e)
    {
      System.out.println("Couldn't configure LF5:");
      e.printStackTrace(System.out);
    }
     */
  }

  /** Creates a new instance of BasisTestCase */
  public BaseTestCase(final String pTestName)
  {
    super(pTestName);
  }


  /**
   * WHy is this missing from JUnit? they have assertNotNull/assertNull but not assertFalse...
   * Consistency in APIs ?!
   * @param msg
   * @param condition
   */
  public static void assertFalse(final String msg, final boolean condition)
  {
    assertTrue(msg, !condition);
  }

  public static void assertNotEquals(final String msg, final boolean b1, final boolean b2)
  {
    assertFalse(msg, b1 == b2);
  }
  public static void assertNotEquals(final String msg, final byte b1, final byte b2)
  {
    assertFalse(msg, b1 == b2);
  }
  public static void assertNotEquals(final String msg, final char b1, final char b2)
  {
    assertFalse(msg, b1 == b2);
  }
  public static void assertNotEquals(final String msg, final int b1, final int b2)
  {
    assertFalse(msg, b1 == b2);
  }
  public static void assertNotEquals(final String msg, final long b1, final long b2)
  {
    assertFalse(msg, b1 == b2);
  }

  public static void assertNotEquals(final String msg, final Object b1, final Object b2)
  {
    assertFalse(msg, b1 == null ? b2 != null : b1.equals(b2));
  }

  public static void assertContainsSame(final String pMsg, final Collection pC1, final Collection pC2)
  {
    assertTrue(pMsg + " C1.containsAll(C2)", pC1.containsAll(pC2));
    assertTrue(pMsg + " C2.containsAll(C1)", pC2.containsAll(pC1));
  }
}
