// START LICENSE
// JSet - a Java JSet card board game implementation
// Copyright (C) 2004 Jerome Lacoste
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// END LICENSE

package org.cb.jset.client.model;

import junit.framework.*;

import java.util.Collection;
import java.util.Arrays;
import java.util.List;

import org.cb.jset.*;
import org.cb.cardboard.CardBoardModel;


/**
 * Test the client board
 * @author jerome@coffeebreaks.org - last modified by $Author: jerome $
 * @version $Id: ClientBoardTest.java 85 2004-04-13 14:29:08Z jerome $
 */
public class ClientBoardTest extends org.cb.jset.BaseTestCase
{
  private JSetClientBoardModel _OUT;
  private CardStack _stack;
  private MatchingSetFinder _setFinder;

  /** Creates a new instance of FlightTargetBO */
  public ClientBoardTest(final String testName)
  {
    super(testName);
  }

  protected void setUp()
  {
    _OUT = new JSetClientBoardModel();
    _stack = new CardStack();
    _stack.shuffle();
    _setFinder = new MatchingSetFinder();
  }

  protected void tearDown()
  {
    _OUT = null;
    _stack = null;
  }

  public static void main(final String[] args)
  {
    junit.textui.TestRunner.run(suite());
  }

  public static Test suite()
  {
    final TestSuite suite = new TestSuite(ClientBoardTest.class);

    return suite;
  }

  public void testCheckSpaces()
  {
    final int lNbCards = 30;
    final CardProperties[] cards = _stack.pop(lNbCards);

    _OUT.addCards(cards);
    assertEquals("All cards added correctly.", lNbCards, _OUT.getElements().size());
    assertEquals("No holes", _OUT.getElements().size(), _OUT.getNbCards());

    int lNbCardsInBoard = lNbCards;
    while (_stack.size() > 0)
    {
      final CardSet[] foundSets = _setFinder.findSets(_OUT.getElements());
      if (foundSets.length != 0)
      {
        try
        {
          _OUT.removeSet(foundSets[0]);
          lNbCardsInBoard -= 3;
        }
        catch (BoardException e)
        {
          fail("failure to remove the set: " + e.getMessage());
        }

        //assertEquals("cards still accounted for: ", , _OUT.getElements().size());
        assertEquals("3 holes after removal of one set.", _OUT.getElements().size(), _OUT.getNbCards() + 3);
      }
      final CardProperties[] newCards = _stack.pop(3);
      _OUT.addCards(newCards);
      lNbCardsInBoard += 3;

      assertEquals("cards still accounted for: ", lNbCardsInBoard, _OUT.getElements().size());
      assertEquals("no more holes.", _OUT.getElements().size(), _OUT.getNbCards());
    }
  }
}
